.. _fluent_pages.urlresolvers:

fluent_pages.urlresolvers
==========================

.. automodule:: fluent_pages.urlresolvers

.. autofunction:: fluent_pages.urlresolvers.app_reverse

.. autofunction:: fluent_pages.urlresolvers.mixed_reverse

.. autofunction:: fluent_pages.urlresolvers.clear_app_reverse_cache

Other classes
-------------

.. autoexception:: fluent_pages.urlresolvers.MultipleReverseMatch

.. autoexception:: fluent_pages.urlresolvers.PageTypeNotMounted

